# Boj-toolkit
나 혼자 쓰려고 만든 백준 툴킷
제출, 문제 파일 생성 등 다양한 기능 제공할 **예정**

## CLI
### 24-08-13
```bash
boj-toolkit add 1000 -l "Python3"
```
add 커맨드만 지원
### 24-08-15
```bash
boj-toolkit add 1000 -l "Python3"
boj-toolkit test 1000                # 아직은 파이썬만 지원
```
add, test 커맨드만 지원